header

# XMLRésuméLibrary: User Guide

head | Element Reference | history

## Name

header — Container for information about the person being described in a résumé

## Synopsis

### Content Model

    (name,address?,birth?,contact?)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `header` element is a container for information typically contained in the header at the top of a résumé. This includes biographic and contact information about the person who the résumé describes.

### Formatting

The `header.format` parameter influences the formatting of headers in all output formats.

### Parents

`header` may be contained in these elements: `resume`

## See Also

`header.format`.

## Examples

    <header>
      <name>
        <firstname>Hector</firstname>
        <surname>Gomez</surname>
      </name>
      <address>
        <street>245 San Bernadino</street>
        <city>Los Gatos</city>
        <state>LX</state>
        <zip>94262</zip>
      </address>
      <birth>
        <date>
          <dayOfMonth>30</dayOfMonth>
          <month>April</month>
          <year>1942</year>
        </date>
      </birth>
      <contact>
        <phone>555-1212</phone>
        <email>hector.gomez@xyz.bob</email>
      </contact>
    </header>

head | Element Reference | history